# New Zealand | Aotearoa National Seismic Hazard Model
The logic tree definitions, final configurations, and versioning of the New Zealand | Aotearoa National Seismic Hazard Model are stored here

For model data see [nshm.gns.cri.nz](https://nshm.gns.cri.nz)